@@ -1,4 +1,11 @@
+#!/usr/bin/env python3
+# -*- coding: utf-8 -*-
+"""
+Created on Wed Apr  22 12:15:12 2020
 
+@license : CeCILL-2.1
+@author: sebastien@gardoll.fr
+"""
 
 import h5py
 import numpy as np
